package com.bonus.canteen.core.cook.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.cook.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.cook.domain.CookEvaluaDetail;
import com.bonus.canteen.core.cook.service.ICookEvaluaDetailService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 订单评价菜品Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "订单评价菜品接口")
@RestController
@RequestMapping("/cook_evalua_detail")
public class CookEvaluaDetailController extends BaseController {
    @Autowired
    private ICookEvaluaDetailService cookEvaluaDetailService;

    /**
     * 查询订单评价菜品列表
     */
    @ApiOperation(value = "查询订单评价菜品列表")
    //@RequiresPermissions("cook:detail:list")
    @GetMapping("/list")
    public TableDataInfo list(CookEvaluaDetail cookEvaluaDetail) {
        startPage();
        List<CookEvaluaDetail> list = cookEvaluaDetailService.selectCookEvaluaDetailList(cookEvaluaDetail);
        return getDataTable(list);
    }

    /**
     * 导出订单评价菜品列表
     */
    @ApiOperation(value = "导出订单评价菜品列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:detail:export")
    @SysLog(title = "订单评价菜品", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出订单评价菜品")
    @PostMapping("/export")
    public void export(HttpServletResponse response, CookEvaluaDetail cookEvaluaDetail) {
        List<CookEvaluaDetail> list = cookEvaluaDetailService.selectCookEvaluaDetailList(cookEvaluaDetail);
        ExcelUtil<CookEvaluaDetail> util = new ExcelUtil<CookEvaluaDetail>(CookEvaluaDetail.class);
        util.exportExcel(response, list, "订单评价菜品数据");
    }

    /**
     * 获取订单评价菜品详细信息
     */
    @ApiOperation(value = "获取订单评价菜品详细信息")
    //@RequiresPermissions("cook:detail:query")
    @GetMapping(value = "/{evaluaDetailId}")
    public AjaxResult getInfo(@PathVariable("evaluaDetailId") Long evaluaDetailId) {
        return success(cookEvaluaDetailService.selectCookEvaluaDetailByEvaluaDetailId(evaluaDetailId));
    }

    /**
     * 新增订单评价菜品
     */
    @ApiOperation(value = "新增订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:detail:add")
    @SysLog(title = "订单评价菜品", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增订单评价菜品")
    @PostMapping
    public AjaxResult add(@RequestBody CookEvaluaDetail cookEvaluaDetail) {
        try {
            return toAjax(cookEvaluaDetailService.insertCookEvaluaDetail(cookEvaluaDetail));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改订单评价菜品
     */
    @ApiOperation(value = "修改订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:detail:edit")
    @SysLog(title = "订单评价菜品", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改订单评价菜品")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CookEvaluaDetail cookEvaluaDetail) {
        try {
            return toAjax(cookEvaluaDetailService.updateCookEvaluaDetail(cookEvaluaDetail));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除订单评价菜品
     */
    @ApiOperation(value = "删除订单评价菜品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:detail:remove")
    @SysLog(title = "订单评价菜品", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除订单评价菜品")
	@PostMapping("/del/{evaluaDetailIds}")
    public AjaxResult remove(@PathVariable Long[] evaluaDetailIds) {
        return toAjax(cookEvaluaDetailService.deleteCookEvaluaDetailByEvaluaDetailIds(evaluaDetailIds));
    }
}
